.. _AHF:

**************
AHF catalogues
**************

The folder ``AHF`` contains the Amiga Halo Finder (AHF) halo and subhalo catalogues. The data is organized following the general hierarchical structure described in :ref:`suite_folders`.

The format of the catalogues is the traditional one from AHF, and we refer the user to the `AHF documentation <http://popia.ft.uam.es/AHF/Documentation.html>`_ for further details.

The data is organized following the generic scheme outlined in :ref:`organization`.
